﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.Mvc;
using System.Web.Mvc.Html;

namespace MvcControlsToolkit
{
    public class AccordionItem: Container
    {
        public string Title { get; set; }
        public string Css { get; set; }
        public bool Selected { get; set; }
        public bool Enabled { get; set; }        

        public AccordionItem(string title):base(title)
        {
            Title = title;
            Enabled = true;
            Selected = false;
            ContentType = ContentType.Static;
            PartialViewName = null;
        }

        /// <summary>
        /// Set the content of the current Tb
        /// </summary>
        /// <param name="contentType">Determines how the content of the tab is to be rendered</param>
        /// <param name="name">If contentType is Static, determines the actual HTML, if contentType is PartialView, determines the view name, otherwise determines the action url</param>
        /// <param name="objectModel">Only when contentType is PartialView. The model to be passed to the view</param>
        /// <param name="viewData">Only when contentType is PartialView. The view data dictionary to be passed to the view</param>
        /// <returns></returns>
        public AccordionItem SetContent(ContentType contentType, string name, object objectModel = null, ViewDataDictionary viewData = null)
        {           
            return base.SetContent(contentType, name, objectModel, viewData) as AccordionItem;
        }

        /// <summary>
        /// Get html code
        /// </summary>
        /// <returns></returns>
        public override string GetHtml()
        {
            string title = string.Format("<h3><a href=\"{0}\">{1}</a></h3>", Action, Title);

            return title;
        }

        /// <summary>
        /// Not use
        /// </summary>
        /// <returns></returns>
        public override string GetJScript()
        {
            throw new NotImplementedException();            
        }

        public override string ToString()
        {
            return GetHtml();
        }
    }
}
